Time and Position Transformation
================================
.. versionadded:: 0.2
.. automodule:: lsl.transform

Time
----
.. autoclass:: lsl.transform.Time
   :members:

Celstial Positions
------------------
.. autoclass:: lsl.transform.CelestialPosition
   :members:
.. autoclass:: lsl.transform.PlanetaryPosition
   :members:
.. autoclass:: lsl.transform.SkyPosition
   :members:
.. autoclass:: lsl.transform.PointingDirection
   :members:

Geographic Positions
--------------------
.. autoclass:: lsl.transform.GeographicalPosition
   :members:

